@@ -17,7 +17,7 @@ import hashlib
 import logging
 from pathlib import Path
 import time
-from typing import Any, AsyncIterator, Callable, Dict, List, Optional
+from typing import Any, AsyncIterator, Awaitable, Callable, Dict, List, Optional, TypeVar
 import uuid
 
 from ..data_filter import empty_filter
@@ -52,6 +52,8 @@ WAIT_MAX_ATTEMPTS = 200
 
 LOGGER = logging.getLogger(__name__)
 
+T = TypeVar("T")
+
 
 class Items(Paged):
     """Asynchronous iterator over items from a paged response."""
@@ -96,6 +98,10 @@ class DataClient:
         if self._base_url.endswith('/'):
             self._base_url = self._base_url[:-1]
 
+    def _call_sync(self, f: Awaitable[T]) -> T:
+        """block on an async function call, using the call_sync method of the session"""
+        return self._session._call_sync(f)
+
     @staticmethod
     def _check_search_id(sid):
         """Raises planet.exceptions.ClientError if sid is not a valid UUID"""
